( cd usr/lib ; rm -rf libgcc_s.so )
( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib ; rm -rf libstdc++.so.6 )
( cd usr/lib ; ln -sf libstdc++.so.6.0.10 libstdc++.so.6 )
( cd usr/lib ; rm -rf libssp.so.0 )
( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so.0 )
